| as.data.frame.list_of_srcref | R Documentation |
Coerce a list_of_srcref object to a data.frame
## S3 method for class 'list_of_srcref'
as.data.frame(
x,
...,
use.names = TRUE,
expand.srcref = FALSE,
row.names = NULL
)
x |
A |
... |
Additional arguments unused |
use.names |
A |
expand.srcref |
A |
row.names |
|
A data.frame with one record per srcref and variables:
Names of the srcref objects, passed using the names of
x if use.names = TRUE
srcref objects if expand.srcrefs = FALSE
The
srcref file location if it can be determined. If an absolute path
can't be found, only the base file name provided in the srcref object and
the numeric components of the srcref objects if expand.srcrefs
= TRUE
pkg <- system.file("examplepkg", package = "covtracer")
install.packages(
pkg,
type = "source",
repos = NULL,
quiet = TRUE,
INSTALL_opts = "--with-keep.source"
)
as.data.frame(pkg_srcrefs("examplepkg"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.