Learn R Programming

covtracer (version 0.0.2)

coverage_has_recorded_tests: Test that the coverage object retains testing information

Description

Test whether the coverage object has expected fields produced when coverage was captured with option(covr.record_tests = TRUE).

Usage

coverage_has_recorded_tests(coverage)

Value

A logical value, indicating whether the coverage object has recorded tests, or NA when it does not appear to have traced any test code.

Arguments

coverage

a covr coverage object

See Also

Other coverage_tests: coverage_check_has_recorded_tests(), coverage_get_tests()