| match_containing_srcrefs | R Documentation |
Provided two lists of srcref objects, find the first srcrefs in r that
entirely encapsulate each respective srcref in l, returning a list of
indices of srcrefs in r for each srcref in l.
match_containing_srcrefs(l, r)
l |
A |
r |
A |
A integer vector of the first index in r that fully encapsulate
the respective element in l
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.