| trace_srcrefs_df | R Documentation |
Extract coverage traces. Traces are the
traced lines of code counted when evaluating code coverage, which are used
for counting expression evaluation. Each traced is a unique expression within
a package's source code.
trace_srcrefs_df(x)
x |
A |
A data.frame, where each record it a trace srcref with
variables:
A character identifier. This will use the names of the
elements of a coverage object,
which are srcref "keys".
A srcref object of the trace source code location
srcrefs test_trace_mapping
Other srcrefs_df:
pkg_srcrefs_df(),
test_srcrefs_df()
options(covr.record_tests = TRUE)
pkg_path <- system.file("examplepkg", package = "covtracer")
cov <- covr::package_coverage(pkg_path)
trace_srcrefs_df(cov)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.