View source: R/pseudo_srcref.R
| with_pseudo_srcref | R Documentation |
Most relevant data can be traced to an existing srcref. However, some data, such as test traces from coverage objects, are likely cleaned up and their srcfiles deleted, causing a barrage of warnings any time these objects are printed.
with_pseudo_srcref(call, file, lloc)
call |
Any code object, most often a |
file |
A filepath to bind as a |
lloc |
A |
A pseudo_srcref adds in the srcref data but continues to preserve the
expression content. This allows these expression objects to be pretty-printed
like srcrefs when included as a list_of_srcref data.frame column.
A with_pseudo_srcref object, mimicking the structure of srcref
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.