Rd_df: Create a tabular representation of man file information
Description
Provides Rd index info with a few additional columns of information about
each exported object. Returns one record per documented object, even if
multiple objects alias to the same documentation file.
Usage
Rd_df(x)
Value
A data.frame of documented object information with variables:
index
A numeric index of documentation files associated with
documentation objects
file
A character filename of the Rd file in the "man" directory
filepath
A character file path of the Rd file in the "man"
directory
alias
character object names which are aliases for the
documentation in filepath
is_exported
A logical indicator of whether the aliased object
is exported from the package namespace